@@ -14,6 +14,8 @@
 
 import typing
 from abc import abstractmethod
+from types import MappingProxyType
+from typing import Mapping
 
 
 class CloudEvent:
@@ -45,6 +47,14 @@ class CloudEvent:
         """
         raise NotImplementedError()
 
+    def get_attributes(self) -> Mapping[str, typing.Any]:
+        """
+        Returns a read-only view on the attributes of the event.
+
+        :returns: Read-only view on the attributes of the event.
+        """
+        return MappingProxyType(self._get_attributes())
+
     @abstractmethod
     def _get_attributes(self) -> typing.Dict[str, typing.Any]:
         """
